#
# spec file for package gpaste
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Simone Tolotti, <simone.tolotti@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude typelib\\(Clutter|St\\)
%global alt_name GPaste
Name:           gpaste
Version:        45.2
Release:        1.1
Summary:        Clipboard management system for GNOME
License:        BSD-2-Clause
Group:          System/GUI/GNOME
URL:            https://github.com/Keruspe/GPaste
# Source url disabled as we are using a git checkout
# Source0:        http://www.imagination-land.org/files/%%{name}/%%{alt_name}-%%{version}.tar.xz
Source0:        %{alt_name}-%{version}.tar.zst
Source99:       gpaste-rpmlintrc
# PATCH-FIX-UPSTREAM
Patch0:         https://patch-diff.githubusercontent.com/raw/Keruspe/GPaste/pull/446.patch
# For directory ownership
BuildRequires:  gnome-shell >= 3.28
BuildRequires:  gobject-introspection-devel >= 1.58.0
BuildRequires:  intltool >= 0.50.0
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(appstream-glib)
BuildRequires:  pkgconfig(clutter-1.0)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gcr-4)
BuildRequires:  pkgconfig(gdk-3.0) >= 3.0.0
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.58.0
BuildRequires:  pkgconfig(gjs-1.0) >= 1.78.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.58.0
BuildRequires:  pkgconfig(gnome-keybindings)
BuildRequires:  pkgconfig(gobject-2.0) >= 2.58.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(vapigen) >= 0.42
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xtst)
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
BuildRequires:  gcc13
%else
BuildRequires:  gcc
%endif

%description
GPaste is a clipboard management daemon with DBus interface.

%package -n libgpaste2-0
Summary:        Library for managing clipboard history
Group:          System/Libraries

%description -n libgpaste2-0
GPaste is a clipboard management daemon with DBus interface.

This package provides a library for managing clipboard history.

%package -n libgpaste-gtk-3-0
Summary:        Library for managing clipboard history
Group:          System/Libraries

%description -n libgpaste-gtk-3-0
GPaste is a clipboard management daemon with DBus interface.

This package provides a library for managing clipboard history.

%package -n libgpaste-gtk4-0
Summary:        Library for managing clipboard history
Group:          System/Libraries

%description -n libgpaste-gtk4-0
GPaste is a clipboard management daemon with DBus interface.

This package provides a library for managing clipboard history.

%package -n libgpaste-gnome-shell-client0
Summary:        Library for managing clipboard history
Group:          System/Libraries

%description -n libgpaste-gnome-shell-client0
GPaste is a clipboard management daemon with DBus interface.

This package provides a library for managing clipboard history.

%package -n typelib-1_0-GPaste-2
Summary:        Introspection bindings for the gpaste clipboard history manager
Group:          System/Libraries

%description -n typelib-1_0-GPaste-2
GPaste is a clipboard management daemon with DBus interface.

This package provides the GObject Introspection bindings for the library
managing clipboard history.

%package -n typelib-1_0-GPasteGtk-3
Summary:        Introspection bindings for the gpaste clipboard history manager
Group:          System/Libraries

%description -n typelib-1_0-GPasteGtk-3
GPaste is a clipboard management daemon with DBus interface.

This package provides the GObject Introspection bindings for the library
managing clipboard history.

%package -n typelib-1_0-GPasteGtk-4
Summary:        Introspection bindings for the gpaste clipboard history manager
Group:          System/Libraries

%description -n typelib-1_0-GPasteGtk-4
GPaste is a clipboard management daemon with DBus interface.

This package provides the GObject Introspection bindings for the library
managing clipboard history.

%package devel
Summary:        Development files for the gpaste clipboard history manager
Group:          Development/Libraries/GNOME
Requires:       libgpaste-gtk-3-0 = %{version}
Requires:       libgpaste-gtk4-0 = %{version}
Requires:       libgpaste2-0 = %{version}
Requires:       typelib-1_0-GPaste-2 = %{version}

%description devel
GPaste is a clipboard management daemon with DBus interface.

This package provides the development files for the library managing
clipboard history.

%package -n gnome-shell-extension-gpaste
Summary:        GPaste status menu extension for GNOME Shell
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Requires:       gnome-shell
Supplements:    (%{name} and gnome-shell)
BuildArch:      noarch

%description -n gnome-shell-extension-gpaste
GPaste is a clipboard management daemon with DBus interface.

This GNOME Shell extension adds a clipboard item in the status
menu, and provides the ability to copy/paste text.

%package zsh-completion
Summary:        Zsh tab-completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
GPaste is a clipboard management daemon with DBus interface.
This package provides zsh tab-completion for %{name}.

%lang_package

%prep
%autosetup -p1 -n %{alt_name}-%{version}

%build
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
export CC=gcc-13
%endif
%meson
%meson_build

%install
%meson_install
desktop-file-edit --set-icon=edit-paste --remove-key Categories --add-category=Applet --add-only-show-in=GNOME %{buildroot}%{_datadir}/applications/org.gnome.GPaste.Ui.desktop
%find_lang GPaste %{?no_lang_C}

%ldconfig_scriptlets -n libgpaste2-0
%ldconfig_scriptlets -n libgpaste-gtk-3-0
%ldconfig_scriptlets -n libgpaste-gtk4-0

%files
%license COPYING
%{_bindir}/gpaste-client
%{_libexecdir}/gpaste/
%{_datadir}/applications/org.gnome.GPaste.Ui.desktop
%{_datadir}/applications/org.gnome.GPaste.Preferences.desktop
%{_datadir}/bash-completion/completions/gpaste-client
%{_datadir}/dbus-1/services/org.gnome.GPaste.Ui.service
%{_datadir}/dbus-1/services/org.gnome.GPaste.Preferences.service
%{_datadir}/dbus-1/services/org.gnome.GPaste.service
%{_datadir}/glib-2.0/schemas/org.gnome.GPaste.gschema.xml
%{_datadir}/metainfo/org.gnome.GPaste.Ui.appdata.xml
%{_mandir}/man1/gpaste-client.1%{?ext_man}
%{_userunitdir}/org.gnome.GPaste.Ui.service
%{_userunitdir}/org.gnome.GPaste.Preferences.service
%{_userunitdir}/org.gnome.GPaste.service

%files -n libgpaste2-0
%{_libdir}/libgpaste-2.so.*

%files -n libgpaste-gtk-3-0
%{_libdir}/libgpaste-gtk-3.so.*

%files -n libgpaste-gtk4-0
%{_libdir}/libgpaste-gtk4.so.*

%files -n typelib-1_0-GPaste-2
%{_libdir}/girepository-1.0/GPaste-2.typelib

%files -n typelib-1_0-GPasteGtk-3
%{_libdir}/girepository-1.0/GPasteGtk-3.typelib

%files -n typelib-1_0-GPasteGtk-4
%{_libdir}/girepository-1.0/GPasteGtk-4.typelib

%files devel
%license COPYING
%doc AUTHORS ChangeLog NEWS README.md
%{_includedir}/%{name}-2/
%{_libdir}/libgpaste*.so
%{_libdir}/pkgconfig/gpaste*.pc
%{_datadir}/gir-1.0/GPaste*.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gpaste-*.deps
%{_datadir}/vala/vapi/gpaste-*.vapi

%files -n gnome-shell-extension-%{name}
%{_datadir}/gnome-shell/extensions/GPaste@gnome-shell-extensions.gnome.org/
%{_datadir}/gnome-shell/search-providers/org.gnome.GPaste.search-provider.ini
%{_datadir}/gnome-control-center/keybindings/42-gpaste.xml

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_gpaste-client

%files lang -f GPaste.lang

%changelog
* Thu Oct 31 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 45.2:
  + Support GNOME 47.
  + Updated translations.
* Mon Sep 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 45.1+14:
  + Support GNOME 47
  + Updated translations.
- Add 446.patch: Fix build on i586 when using GCC 14.
* Wed Apr  3 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 45+12 (identifies as 45.1, but no git tag
  present, boo#1222276).
  + Support gnome 46.
  + Updated translations.
* Thu Mar  7 2024 Max Lin <mlin@suse.com>
- Build gpaste with gcc13 on Leap 15
- Added gpaste-rpmlintrc for bypass shlib-policy-name-error check
  with Leap15/SLE15 rpmlint
* Wed Jan 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop pkgconfig(mutter-clutter-13) BuildRequires: no longer needed
  since version 45.
* Sun Sep 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45:
  + Port to gnome 45
  + Add setting to open ui window centered
  + Updated translations.
- Drop gpaste-bump-mutter-dep.patch: fixed upstream.
- Switch compression to zst in both service and tarball produced.
* Sat Aug 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add gpaste-bump-mutter-dep.patch: Bump mutter-clutter dependency
  to version 13. Following this replace
  pkgconfig(mutter-clutter-12) with pkgconfig(mutter-clutter-13)
  BuildRequires.
* Mon Jul 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Fix a bug leading to history with only one item.
- Changes from version 44.0:
  + gcr 4 is now required.
  + Port to gnome 44.
* Mon Mar 27 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Filter out St typelib dependency.
* Fri Mar 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.2+6:
  + Support GNOME 44.
  + Updated translations.
- Replace pkgconfig(mutter-clutter-11) with
  pkgconfig(mutter-clutter-12) following upstream changes.
- Stop passing gcr3=false to meson, no longer needed.
* Fri Mar 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.2:
  + Avoid crash under heavy memory load.
* Mon Feb 27 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Replace mutter-devel with pkgconfig(mutter-clutter-11), align
  with what meson checks for.
* Mon Feb 27 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix _service version rewrite to not have TAG+0 versions.
* Sun Feb 26 2023 Andrey Gankov <gav@qsolution.ru>
- Update to version 43.1:
  + Respect --use-index when displaying history
  + Open GPaste UI where the mouse pointer is
  + Internal preparation for gtk4 port
  + Translations updates
- Disable gcr3 default Meson build option to keep using GCR
  version 4.
* Sun Sep 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.1+29:
  + build-sys:
  - update to gnome-shell 43
  - update to GCR 4
- Switch to source service.
- Add pkgconfig(gcr-4) BuildRequires following upstream changes.
- Package sub-package gpaste-zsh-completion as noarch.
* Sat Mar 26 2022 Andrey Gankov <gav@qsolution.ru>
- Update to 42.1:
  * Fixes to the new preferences tool.
  * Style fixes.
  * Translations updates.
- Changes from version 42.0:
  * Old libgpaste replaced by a new minimal libgpaste-2 with no gtk
    dependency.
  * New libgpaste-gtk3 for utils and settings ui.
  * New libgpaste-gtk4 for utils and preferences ui.
  * New gtk4 based gpaste-preferences utility.
  * Autotools are no longer supported.
  * Extension updated for gnome-shell 42.
  * Translations updates.
- Changes from version 3.42.6:
  * Fix the storage path in meson builds.
- Remove gpaste-bump-mutter-clutter.patch.
- Remove subpackages: typelib-1_0-GPaste-1_0, libgpaste13
- Add pkgconfig(gtk4) and pkgconfig(libadwaita-1) BuildRequires:
  new dependencies.
- Add subpackages: libgpaste2-0, libgpaste-gtk-3-0,
  libgpaste-gtk4-0, typelib-1_0-GPaste-2, typelib-1_0-GPasteGtk-3,
  typelib-1_0-GPasteGtk-4
* Wed Feb 16 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.42.5:
  * Fix some race conditions in history handling.
  * Better fix crash when there is no history yet.
  * Fix crash when there is no history yet.
- Remove 1ec2699daa600e34d73b8d200dd7bb22f4eace27.patch.
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 1ec2699daa600e34d73b8d200dd7bb22f4eace27.patch: Fix build
  with meson 0.61 and newer.
- Use ldconfig_scriptlets macro for post(un) handling.
* Wed Jan 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add gpaste-bump-mutter-clutter.patch: Bump mutter-clutter version
  needed.
* Wed Nov 24 2021 Andrey Gankov <gav@qsolution.ru>
- Update to version 3.42.2:
  + Fix gnome-shell extension when the daemon restarts.
  + Updated translations.
- Changes from version 3.42.1:
  + Fix keybindings on wayland.
  + Updated translations.
* Tue Oct 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Split zsh-completion support out into it's own package.
- Enable lto, gpaste now builds with it enabled.
* Mon Oct 11 2021 Andrey Gankov <gav@qsolution.ru>
- Update to version 3.42.0:
  + Port to gnome-shell 41
  + Updated translations.
- Remove gpaste-gnome-41.patch: It is fixed in upstream.
- Replace syntax packageand to boolean dependencies.
* Mon Aug 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.40.2:
  + fix a crash in memory usage checking.
- Add gpaste-gnome-41.patch: conditionally applied when building
  against mutter 41.
- Replace pkgconfig(mutter-clutter-8) BuildRequires with
  mutter-devel: make it easier to support multiple versions.
- Switch to meson build system:
  + Add meson BuildRequires.
  + Replace configure/make/make_install macros with
    meson/meson_build/meson_install.
* Tue Apr 20 2021 Andrey Gankov <gav@qsolution.ru>
- Update to version 3.40.1:
  + fix build with meson
- Changes from version 3.40.0:
  + port to gnome-shell 40
  + placeholder for gnome-shell prefs
- Replace pkgconfig(mutter-clutter-7) with
  pkgconfig(mutter-clutter-8) BuildRequires
* Fri Mar 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.38.6:
  + fix X11 keybinder outside of GNOME.
* Sun Feb  7 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.5:
  + Better handling and reporting of invalid uuids passed to
    gpaste-client.
  + gpaste-client now has a --use-index argument for several
    subcommands to use index instead of uuid.
* Thu Jan 21 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.4:
  + Fix the make-password keybinding.
  + Updated translations.
* Wed Nov 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.38.3:
  + gnome-shell extension warning fixes.
- Changes from version 3.38.2:
  + gnome-shell extension cosmetic updates.
- Changes from version 3.38.1:
  + Disable images support by default (can be reenabled in
    preferences).
  + Search now includes passwords (using their names).
  + systemd integration enhancements.
- Changes from version 3.38.0:
  + Drop the Tracking DBus signal.
  + Switch to uuids to identify items.
  + Bump DBus interface to org.gnome.GPaste2.
  + Update to gnome-shell 3.38.0
- Replace pkgconfig(mutter-clutter-6) with
  pkgconfig(mutter-clutter-7) BuildRequires following upstreams
  changes.
- Rename libgpaste11 subpackage to libgpaste13, following upstreams
  soname change.
* Sun Apr 26 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.3:
  + Fix activating items using Ctrl-Number in gnome-shell.
- Changes from version 3.36.2:
  + Fix keybinding regrab with gnome-shell.
- Changes from version 3.36.1:
  + Fix keybinding grab with gnome-shell.
- Changes from version 3.36.0:
  + Update to gnome-shell 3.36.0.
- Changes from version 3.34.4:
  + Fix activating items using Ctrl-Number in gnome-shell.
- Changes from version 3.34.3:
  + Fix keybinding regrab with gnome-shell.
- Changes from version 3.34.2:
  + Fix keybinding grab with gnome-shell.
- Replace pkgconfig(mutter-clutter-5) with
  pkgconfig(mutter-clutter-6) BuildRequires following upstreams
  changes.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Oct 25 2019 Andrey Gankov <gankov@opensuse.org>
- Update to version 3.34.1:
  + Compatibility with recent appstream-glib
- Changes from version 3.34.0:
  + Update to gnome-shell 3.34.0
- Replace pkgconfig(mutter-clutter-4) BuildRequires with
  pkgconfig(mutter-clutter-5), following upstreams changes for
  GNOME 3.34.
* Sat Jul 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Disable LTO, gpaste fails to build with it.
* Tue May  7 2019 Andrei Dziahel <develop7@develop7.info>
- Update to version 3.32.0
  + Update to gnome-shell 3.32.0
  + Allow loading settings from ~/.config/gpaste/settings
- Replace pkgconfig(mutter-clutter-3) with
  pkgconfig(mutter-clutter-4) BuildRequires following upstreams
  changes.
* Fri Oct  5 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Workaround a bug in gnome-shell 3.30.0.
- Changes from version 3.30.0:
  + Silence warnings with gcc 8.
  + Update dependencies for gnome 3.30.
- Replace pkgconfig(mutter-clutter-2) with
  pkgconfig(mutter-clutter-3) BuildRequires following upstreams
  changes.
* Tue Jun 12 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Fix a crash in images support.
- Changes from version 3.28.1:
  + Gnome-shell extension cleanups.
  + Allow disabling the confirmation dialog for emptying history.
- Drop gpaste-clutter-2.patch: Fixed upstream.
- Change soname to libgpaste11 from libgpaste10 following upstreams
  bump.
* Tue Apr  3 2018 jengelh@inai.de
- Update summaries.
* Thu Mar 15 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + gpaste-daemonn now emits a dbus signal when an item is
    selected.
  + gpaste-client can now print the history in reverse order.
  + Drop gtk4 support, it will come back later.
  + API adjustments to prepare for the future gtk4 port.
  + Ask confirmation before emptying an history.
- Replace pkgconfig(mutter-clutter-1) BuildRequires with
  pkgconfig(mutter-clutter-2), following upstreams changes for
  GNOME 3.28.
- Rename libgpaste9 subpackeg to libgpaste10, following upstreams
  soname bump.
- Add gpaste-clutter-2.patch: specify the Clutter version to be
  2 instead of 1.
- Filter out typelib(Clutter) dependency: this is provided
  internally by mutter.
* Sat Sep 16 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Javascript modernizations.
  + Adapt to gjs 1.50.
  + Adapt to gnome-shell/mutter 3.26.
  + Use the new clipboardText feature in the search provider.
  + Gtk4 3.91.2 compatibility.
- Replace pkgconfig(mutter-clutter-0) with
  pkgconfig(mutter-clutter-1) BuildRequires: following upstream
  changes.
- Drop obsolete post(un) handling of
  glib2_gsettings_schema_post(un) and desktop_database_post(un)
  macros: No longer needed as file-trigger takes care of this now.
  Also drop glib2_gsettings_schema_requires macro, now obsolete.
- Run spec-cleaner, modernize spec.
* Wed Aug 16 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + `gpaste-client add` now accepts reading from stdin.
  + You can't have two passwords with the same name in the history
    anymore.
  + Prevent a bug adding a password both as password and text in
    some cases.
* Sat Apr 15 2017 gankov@opensuse.org
- Update to version 3.24.1:
  + Fix a regression in Passwords handling.
- Changes from version 3.24.0:
  + Change the history format to 2.0 to be more flexible (backward
    compatible).
  + Unify and consolidate some clipboard interactions.
  + Handle text/html and text/xml mime types.
- Changes from version 3.23.90:
  + Applet and unity app-indicator have been removed.
  + A minimal applet is available there:
    https://github.com/Keruspe/gpaste-applet
  + Dutch translation has been added.
  + gtk4 is now supported (--with-gtk=4.0).
  + gnome-shell/mutter 3.24 are now supported and required.
  + UI will now close when you select an item (configurable).
  + More intuitive search interactions in the ui.
  + Preparations for future other storage backends.
  + Preparations for mime types support.
  + More reliable "paste" behaviour part in some corener cases.
- Changes from version 3.22.3:
  + Fix switch in gnome-shell extension.
  + Fix some wrongly detected growing line.
- Changes from version 3.22.2:
  + Fix memory leaks in the debugging logs.
  + Fix some corner case in images handling.
  + Fix crash in UI when refreshing during search.
  + Stability improvements.
- Changes from version 3.22.1:
  + Fix some build system issues for vala and
    gobject-introspection.
- Changes from version 3.22.0:
  + Depend on gtk+ 3.22, glib 2.50, gobject-introspeciton 1.50.
  + Bug fixes and simplifications in pagination handling for
    gnome-shell.
  + Fix bug with clipboard/primary selection synchronisation.
  + Fix racy calls to gtk_clipboard_store.
- Changes from version 3.21.91:
  + Lots of fixes in the gnome-shell extension pagination.
  + Fix a crash when trying to add binary data with gpaste-client.
  + Use GLib new structured logging.
  + Update appstream files.
- Changes from version 3.21.90:
  + Port from intltool to gettext.
  + pkg-config 0.29 is now required.
  + Port to the internal mutter-clutter.
  + gnome-shell extension cleanup.
  + Add pagination to gnmoe-shell extension.
- Changes from version 3.20.6:
  + Fix switch in gnome-shell extension.
  + Fix refresh with search in the ui.
  + Fix some wrongly detected growing line.
- Changes from version 3.20.5:
  + Fix memory leaks in the debugging logs.
  + Fix some corner case in images handling.
  + Stability improvements.
- Add pkgconfig(mutter-clutter-0) and pkgconfig(gjs-1.0)
  BuildRequires: new dependencies.
- Rename libgpaste6 subpackage to libgpaste9, following upstreams
  soname bump.
* Fri Nov 11 2016 dimstar@opensuse.org
- Add pkgconfig(systemd) BuildRequires: ensure to have the user
  services installed.
* Fri Jul 29 2016 gankov@opensuse.org
- Update to version 3.20.4 (boo#1009441):
  + Fix some extensive CPU usage in some cases.
* Tue Jun 14 2016 gankov@opensuse.org
- Update to version 3.20.3:
  + Fix soname versioning.
- Changes from version 3.20.2:
  + Add missing icon.
- Changes from version 3.20.1:
  + Fix crash when a search goes wrong.
  + Fix hanging issue due to gtk+ race (?) in gtk_clipboard_store.
  + Fix the gnome-shell menu sometimes displaying twice.
  + Add debug logs to the core library.
  + Fix some build issues with some toolchains.
  + Updated translations.
- Drop gpaste-support-gnome-shell-3_16.patch: fixed upstream.
* Sun May 22 2016 badshah400@gmail.com
- Add gpaste-support-gnome-shell-3_16.patch: "Fake" compatibility
  with gnome-shell 3.16.x by patching the metadata file
  (boo#980421).
* Thu Mar 31 2016 lidongyang@suse.com
- Update to version 3.20:
  + Relicensing from GPL-3 to BSD-2.
  + Detect the presence of more features at runtime instead of
    compile time.
  + The gpaste-client cli has been mostly rewritten.
  + gpaste-client file now supports adding images to the history.
  + The legacy gpaste cli is gone.
  + gnome-shell extension cleanups and compatibility with 3.20.
  + automake 1.15 is required.
  + pkg-config 0.27 is required.
  + gtk+ 3.20, vala 0.32 (if –enable-vapi) and
    gobject-introspection 1.48 are required.
  + gpaste-ui now has a "new" button to add new contents to the
    clipboard.
  + The daemon now reexecs itself on SIGUSR1.
  + Avoid having two passwords under the same name in history.
  + libgpaste now logs into its own G_LOG_DOMAIN.
  + GPaste components now write their pid to a file.
  + A new tool is provided for debugging, but not installed:
    clipboard-watcher.
  + systemd user units are provided.
  + Build system cleanups.
  + Outdated translations have been dropped.
  + gobject-introspection fixes.
  + Fix style with gtk+ 3.20.
  + Implement the new shortcut window from gtk+.
  + Various code cleanups.
- Changes from version 3.18.3:
  + Fix synchronisation issues between clipboard and primary
    selection.
  + Fix a memory leak.
  + Never handle images when images support is disabled.
- Rename libgpaste4 subpackage to libgpaste6, following upstreams
  soname bump.
* Tue Dec  1 2015 lidongyang@suse.com
- Update to version 3.18.2:
  + Fix disabling legacy cli.
  + Fix gnome-shell empty button.
  + Fix emptying the active history.
  + Fix showing about dialog.
  + Updated translations.
- Changes from version 3.18.1.1:
  + Few build system cleanups.
  + gobject-introspection fixes.
- Changes from version 3.18.1:
  + Fix a regression in growing lines detection.
- Changes from version 3.18:
  + Warning, this is a big release, with changes in API, you might
    have to kill your old daemon after upgrading.
  + The "gpaste" cli is now "gpaste-client". old name can still be
    enabled with –enable-cli for now.
  + The "gpaste settings" tool is gone, use the "burger" menu from
    "gpaste-client ui".
  + The graphical tool now allows you to fully manage your
    histories.
  + The graphical tool now allows you to restart the daemon.
  + The graphical tool now allows you to edit an element from the
    history.
  + The graphical tool new allows you to upload an element to a
    pastebin service (requires wgetpaste).
  + The graphical tool now displays the size of each history.
  + The graphical tool now displays the index of each element in
    the history.
  + The graphical tool has been slightly redisigned.
  + A new gnome-shell search-provider is provided by the daemon.
  + When searching e.g. "42", the 42nd element from hsitory will
    be included in search results.
  + gpaste-client gained a new subcommand: "get-history" to get
    the name of the current history.
  + gpaste-client gained a new subcommand: "replace" to replace
    the content of an item in the history.
  + Compatibility with gnome-shell 3.18.
  + The daemon now "works" on wayland using XWayland and
    gnome-shell 3.18.
  + The dbus interface name is now org.gnome.GPaste1.
  + The "Empty" dbus method has been renamed "EmptyHistory".
  + The "NameLost" and "ReexecuteSelf" dbus signals are gone.
  + Three new dbus signals: "DeleteHistory", "EmptyHistory" and
    "SwitchHistory".
  + The daemon gained new dbus methods: GetItemKind, GetElements,
    GetHistoryName, Replace.
  + BackupHistory EmptyHistory and DeleteHistory now take the
    history as a parameter instead of the current one.
  + GPasteClient hasn’t the "name-lost" and "reexecute-self"
    signals anymore.
  + GPasteClient gained three new signals: "delete-history",
    "empty-history" and "switch-history".
  + GPasteHistory gained a new "switch" signal.
  + GPasteHistory now tracks dconf to switch between histories.
  + A few formerly private constructors and methods are now
    publicly available.
  + The way GPaste handles dbus conection and objects have
    significantly been reworked.
  + Everything is now handled using 64bits types (the numeric
    settings have thus been reset and some max values changed).
  + A lot of code cleanup and rearchitecturation.
  + Signals are now properly documented for gobject-introspection
    and thus bindings.
  + Various build system cleanups (gobject-introspection and
    vapigen are now required to build from git).
  + Shell completion updates.
  + Updated translations.
- Changes from version 3.16.3.1:
  + Fix a regression in growing lines detection.
- Changes from version 3.16.3:
  + Various gnome-shell extension fixes.
  + Prevent potential crash from external library users.
- Rename libgpaste3 subpackage to libgpaste4, following upstream
  soname change.
* Wed Jul 29 2015 lidongyang@suse.com
- Update to version 3.16.2.1:
  + Fix error in pipe detection.
- Changes from version 3.16.2:
  + Allow password to be taken from stdin.
- Changes from version 3.16.1:
  + Bump max history size.
  + Fix weird behaviour wrt screensaver.
- Changes from version 3.16:
  + New subcommand: gpaste merge to merge various entries
    (with –decoration and –separator).
  + New tool: gpaste-ui (minimal graphical interface).
  + Legacy applet reworked to use gpaste ui.
  + Ubuntu app indicator reworked to use gpaste ui.
  + New keybinding to launch gpaste ui.
  + New keybinding to upload clipboard content to a pastebin
    service (requires wgetpaste >= 2.26).
  + The daemon now returns standard DBus errors on invalid input.
  + Name dbus parameters.
  + Gnome-shell 3.16 support (require gnome-shell 3.16 because
    of breaking changes).
  + Require glib 2.44 and gtk 3.16.
  + Compatibility with new glib autoptr mechanism.
  + Fully switch to appstream.
  + Updated shell completions.
  + Various libgpaste api cleanups (bump soname to 3,
    rework libtool versioning).
  + Detect applet and app-indicator at runtime instead of
    build time.
  + Fix bug with recent glib.
  + Make a lot more stuff async.
  + Gpasted is dead (long live gpaste-daemon).
  + Changed DBus signal is dead.
  + Drop old ubuntu compat patches.
  + Drop gpaste-config.h.
  + Drop old manual pages for applet and app-indicator.
  + Drop legacy gpaste subcommands (raw, oneline, zero, favor
    –raw, –oneline and –raw).
  + Various bugfixes.
  + Some progress regarding wayland support.
- Changes from version 3.14.3:
  + Fix crashes related to images support.
- Changes from version 3.14.2:
  + Improve zsh completion.
  + Fix a bug causing the gnome-shell extension to randomly crash.
- Changes from version 3.14.1:
  + Search is now always done by the daemon, not the gnome-shell
    extension.
  + New gpaste subcomand: search.
  + Gpaste now accepts --online --raw and --zero options.
  + Search is now async.
  + Various gnome-shell extension fixes.
  + Updated completions.
  + We now restore the clipboard contents when unlocking the
    screensaver.
  + Updated translations.
- Rename libgpaste2 subpackage to libgpaste3, following upstream
  soname change.
* Wed Feb 18 2015 develop7@develop7.info
- Move GPaste.Settings.service out of -devel, enabling regular
  users to run GPaste settings.
* Tue Dec 16 2014 zaitor@opensuse.org
- Add explicit pkgconfig(gnome-keybindings) BuildRequires:
  configure looks for it.
- Add pkgconfig(vapigen) BuildRequires and pass --enable-vala to
  configure: build vala bindings.
* Mon Nov 24 2014 dimstar@opensuse.org
- Update to version 3.14 (boo#905909):
  + Update for latest gobject-introspection.
  + Support gnome-shell 3.14.
  + Start redesign of the gnome-shell extension.
  + New gpaste show-history command.
- Changes from version 3.12.3.1:
  + A bug preventing the history to be saved to disk has been
    fixed.
  + Prevent a segfault when loading large histories.
  + Add a new gpaste oneline-history command.
- Changes from version 3.12.3:
  + gpaste-daemon now has an Update dbus signal more precise than
    Changed.
  + Desktop files fixes.
  + All calls to clipboard are now async.
  + Performance improvements.
  + gpaste-client has been updated to match gpaste-daemon changes
    with an update signal.
  + gnome-shell extension has been ported to the update signal.
  + applets have been ported to the update signal.
  + gnome-shell search bar now matches the user theme.
- Changes from version 3.12.2:
  + gpasted has been renamed gpaste-daemon.
  + Desktop files have been fixed.
  + Fixes for the ubuntu app-indicator.
  + Keybinding to mark an item as being a password.
  + All libgpaste-* have been merged into a single libgpaste.
  + Misc bugfixes reported for debian packaging.
- Changes from version 3.12.1:
  + Systemd support has been removed.
  + GPaste is now compliant with
    https://wiki.gnome.org/HowDoI/DBusApplicationLaunching
  + GPaste now has built-in support for managing passwords, blog
    post coming.
  + Completions and man pages have been updated.
  + Translations have been updated.
  + Miscellaneous bugfixes with static analysis.
  + The search feature of the gnome-shell extension has been
    improved.
- Rework subpackages, following upstream changes:
  + Drop libgpaste-core4, libgpaste-daemon1, libgpaste-keybinder3,
    libgpaste-applet1, libgpaste-settings1 and libgpaste-client3.
  + New subpackage libgpaste2.
- Drop gpaste-gnome-shell-version-3.12.2.patch: fixed upstream.
* Fri Jun  6 2014 gankov@opensuse.org
- Update to version 3.12:
  + Improved compatibility with GNOME 3.12
- Changes from version 3.10.1
  + gpasted no longer fails at runtime if gnome-shell's settings
    schema is not installed
  + growing lines are detected for lines getting expanded at their
    left too
  + gnome-shell extension has been rewritten
  + gnome-shell extension now has a search bar
  + translations update
  + misc bugfixes
- Changes from version 3.10
  + Follow GNOME versionning
  + Don't display error on daemon-reexec
  + Fix coredumps due to g_error
  + New library: libgpaste-applet
  + Unity support (for Ubuntu 14.04 and above) using
    libgpaste-applet
  + Port legacy applet to libgpaste-applet and rename to StatusIcon
  + Redesign GPaste StatusIcon to make it simpler and similar to
    gnome-shell extension
  + Vala is no longer required to build the applet (rewritten in C)
  + Lower automake dependency to 1.11
  + Be compatible with gnome-shell up to 3.12
  + libgpaste-settings: add reset
  + gpaste settings: add reset buttons
  + gpaste settings: add a switch to enable the gnome-shell
    extension
  + The gnome-shell gsettings schema is now required when
  - -enable-gnome-shell-extension is provided (default)
  + gpasted: GetElement now returns the display string
  + gpasted now forwards the full history via dbus, letting the
    client manage the display limit
  + gpasted gained GetHistoryLength, GetRawHistory, GetRawElement
    and About
  + gpasted gained a new Version property
  + Add about dialog to all components
  + Prefer dark theme
  + Display more info at the end of configure
  + Provide appdata files
  + Parallel build fixes
  + Fix build issues for Fedora, Ubuntu and Debian
  + clang related fixes
  + Fix warnings
  + Translations update
- Changes from version 3.8
  + Fix german translation
  + No longer depend on libxml
  + Update Portugueuse and French translations
  + New growing-lines feature
  + Misc bufixes
- Create new subpackage for the new libgpaste-applet1 library
- Replace subpackage to new version of libraries(libgpaste-client3,
  libgpaste-core4).
- Add gpaste-gnome-shell-version-3.12.2.patch
* Sat Dec  7 2013 gankov@opensuse.org
- Update to version 3.7:
  + "Paste and Pop" is now only "Pop"
  + Fix SEGV when deleting last item of history
  + New gnome-shell DBus client library
  + DBus client libraries are now async
  + Keybinder now uses gnome-shell if available to grab keys
  + Preparations for wayland port
  + Enhance internal memory management
  + Code cleanup
  + Misc bug fixes
  + German translation
- Changes from version 3.6:
  + GPaste settings look has been updated to better fit with recent
    GNOME
  + Performance improvements
  + Daemon now fully evenmential (no more polling, less power
    consuption)
  + GPasteClipboard now has a "owner-change" signal similar to
    GtkClipboard's one
  + Misc. bugfixes
  + New setting to set the maximum amount of memory used by data in
    history
  + FIFO mode has been dropped (lacking design)
  + Code cleanup and modernisation
  + g_paste_history_add is now transfer full
- Create new subpackage for the new libgpaste-gnome-shell-client0
  library.
- Replace subpackage to new version of libraries(libgpaste-client2,
  libgpaste-keybinder3, libgpaste-core3).
* Sun Oct 13 2013 gankov@opensuse.org
- Update to version 3.5:
  + Compatibility with gnome-shell 3.9.90 and above
  + The gnome-shell applet has totally been rewritten and is now
    more intuitive.
  + Port to newer glib
  + Don't use deprecated stuff from gtk+
  + The X11 keybinder is now optional
  + New keybinding to sync the clipboard to the primary selection
  + New keybinding to sync the primary selection to the clipboard
- Remove gpaste-gnome-3.9.patch
* Thu Jul 25 2013 gankov@opensuse.org
- Update to version 3.0.2:
  + Fix build without gnome-control-center installed
  + Fix focus when using <Ctrl><Alt><H< in gnome-shel extension
- Changes from version 3.0.1:
  + Fix build.
- Changes from version 3.0:
  + Various build fixes.
  + Support of gnome-control-center for setting keybindings.
  + Compatibility with newer gnome-shell.
- Changes from version 2.99.2:
  + Fix a bug making gpaste settings ui a no-op.
  + Don't close legacy applet menu when deleting an item.
  + Fix vala bindings.
  + Updated translations,
- Changes from version 2.99.1:
  + Fix a few typos in the conditional code for applet and
    extension.
  + Fix make install when GPaste is not yet installed.
  + Clean desktop files.
- Changes from version 2.99:
  + Compatibility with recent development releases of gnome-shell.
  + "gpaste f" now defers the file reading to the GPaste daemon.
  + libgpaste-client does now fully cover the GPaste DBus API.
  + libgpaste-keybinder has been ported to use XInput2.
  + keybindings have been fixed.
  + The gnome-shell extension has been ported to use
    libgpaste-client.
  + A systemd user unit is now provided.
  + New library: libgpaste-settings-ui.
  + gpaste-settings has been ported to libgpaste-settings-ui.
  + The gnome-shell extension now has a pref.js module based on
    libgpaste-settings-ui.
  + An autostart desktop file is now provided with the legacy
    applet.
  + gobject-introspection and vala support are now optional.
  + Various code cleanup.
- Add gpaste-gnome-3.9.patch: Declare GNOME 3.9.x as compatible.
* Sun Dec  2 2012 dimstar@opensuse.org
- Update to version 2.9.1:
  + Fix memory leak when handling images.
  + Fix duplicated images in history.
  + Fix "changed" signal in GPasteSettings.
* Wed Oct 10 2012 dimstar@opensuse.org
- Update to version 2.9:
  + Now depends on intltool 0.50
  + Automake stack is even more modular
  + libgpaste has been split into sublibs: libgpaste-core,
    libgpaste-keybinder and libgpaste-settings
  + New libraries: libgpaste-client and libgpaste-daemon
  + gpaste CLI is rewritten in C
  + Keybindings have totally been reworked
  + Performance improvements
  + Various code cleanup
  + Images support can now be disabled
  + Paste and Pop keybinding may behave weirdly because of gtk+
- Drop libgpaste1 sub-package: this library name no longer exists.
- Create new subpackages for the new libs (libgpaste-core1,
  libgpaste-keybinder1, libgpaste-settings1, libgpaste-client0 and
  libgpaste-daemon1).
* Sun May  6 2012 dimstar@opensuse.org
- Update to version 2.8.1:
  + Fix crash in gpaste_daemon_tracking.
* Thu May  3 2012 badshah400@gmail.com
- Update to version 2.8:
  + Various cleanup and bugfixes.
  + The history file now has a version number.
  + CDATA can now be copied.
  + ToggleHistory is now ShowHistory.
  + The "keyboard-shortcut" preferences is now called
    "show-history".
  + New feature : Paste & Pop with a new keybinding (experimental).
  + FIFO mode.
  + Multi-history with "gpaste backup-history" and "gpaste
    switch-history".
  + New commands: "gpaste delete-history" and "gpaste
    list-histories".
  + gpaste-settings has been rewritten.
  + libgpaste improvements.
  + vapi is no longer shipped and is generated when building.
  + Now requires automake 1.12 and autoconf 2.69.
  + Updated translations.
- Rename libpaste0 subpackage to libgpaste1, following upstream
  soname change.
* Wed Apr 25 2012 vuntz@opensuse.org
- Update to version 2.5:
  + New library to externalize the core: libgpaste written in C
    with introspection and vapi
  + Port gpasted to libgpaste and rewrite it in C
  + Port gpaste-settings to libgpaste
  + Port gpaste-applet to libgpaste
  + Reexecute has now a signal: ReexecuteSelf
  + Small bug fixes
  + Various build system cleanup
- Cleanup for inclusion in Factory.
* Tue Feb 14 2012 simone.tolotti@gmail.com
- New package, imported from Fedora package (and update to 2.2.1).
